@@ -1,4 +1,4 @@
-# Copyright 2020 The Tekton Authors
+# Copyright 2021 The Tekton Authors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,7 +14,6 @@
 
 import os
 
-
 def is_running_in_k8s():
     return os.path.isdir('/var/run/secrets/kubernetes.io/')
 
@@ -35,13 +34,6 @@ def get_tekton_namespace(tekton):
     namespace = tekton_namespace or get_default_target_namespace()
     return namespace
 
-
 def get_tekton_plural(tekton):
     tekton_plural = str(tekton.kind).lower() + "s"
     return tekton_plural
-
-def check_entity(entity):
-    valid_entities = ['task', 'taskrun', 'pipeline', 'pipelinerun']
-    if entity not in valid_entities:
-        raise RuntimeError("The entity %s is not support, currently supported entities: %s" %
-                           (entity, valid_entities))
